==> forms-v5.2.1.tar.gz: forms/l10n/es_MX.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formularios",
    "{user} has shared the form {formTitle} with you" : "{user} ha compartido el formulario {formTitle} con usted",
    "{user} has shared the form {formTitle} with group {group}" : "{user} ha compartido el formulario {formTitle} con el grupo {group}",
    "Anonymous user" : "Usuario anónimo",
    "A form has been <strong>shared</strong> with you" : "Se ha <strong>compartido</strong> un formulario con usted",
    "Someone <strong>answered</strong> a form" : "Alguien <strong>respondió</strong> a un formulario",
    "Timestamp of data load" : "Timestamp de la carga de datos",
    "Copy" : "Copiar",
    "Anonymous response" : "Respuesta anónima",
    "Shared by %s" : "Compartido por %s ",
    "Forms including questions and submissions" : "Formularios incluyendo preguntas y envíos",
    "responses" : "respuestas",
    "User ID" : "ID de usuario",
    "User display name" : "Nombre a mostrar del usuario",
    "Timestamp" : "Marca de tiempo",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Encuestas y cuestionarios sencillos, autoalojados.",
    "An error occurred while loading the forms list" : "Ha ocurrido un error al cargar la lista de formularios",
    "Form not found" : "Formulario no encontrado",
    "Unable to create a new form" : "No es posible crear un nuevo formulario",
    "Unable to copy form" : "No se ha podido copiar el formulario",
    "New form" : "Nuevo formulario",
    "Shared with you" : "Compartido con usted",
    "Loading forms …" : "Cargando formularios …",
    "No forms created yet" : "Aún no se han creado formularios",
    "Create a form" : "Crear un formulario",
    "Select a form or create a new one" : "Seleccionar un formulario o crear uno nuevo",
    "Please select a form" : "Por favor, escoge un formulario",
    "Create new form" : "Crear nuevo formulario",
    "This form does not exist" : "Este formulario no existe",
    "Form expired" : "El formulario ha expirado",
    "This form has expired and is no longer taking answers" : "Este formulario ha expirado y ya no recibe respuestas",
    "Error while saving configuration" : "Error al guardar la configuración",
    "Error while reloading config" : "Error al recargar la configuración",
    "Form creation" : "Creación del formulario",
    "Restrict form creation to selected groups" : "Restringir la creación de formularios a los grupos seleccionados",
    "Select groups" : "Seleccionar grupos",
    "Form sharing" : "Compartir formularios",
    "Allow sharing by link" : "Permitir compartir a través de enlaces",
    "Allow sharing to all logged in accounts" : "Permitir compartir a todos los usuarios con cuentas",
    "Delete form" : "Eliminar formulario",
    "Expired {relativeDate}" : "Expirado {relativeDate}",
    "Expires {relativeDate}" : "Expira en {relativeDate}",
    "Error while deleting {title}" : "Error al borrar {title}",
    "Form actions" : "Acciones de formulario",
    "Edit form" : "Editar formulario",
    "Share form" : "Compartir formulario",
    "Results" : "Resultados",
    "Copy form" : "Copiar formulario",
    "Are you sure you want to delete {title}?" : "¿Está seguro que desea borrar {título}?",
    "Cancel" : "Cancelar",
    "Options" : "Opciones",
    "Go to previous page" : "Ir a la página anterior",
    "Answer number {index}" : "Respuesta número {index}",
    "Error while saving the answer" : "Error mientras se guardaba la respuesta",
    "Delete answer" : "Borrar respuesta",
    "This question needs a title!" : "Esta pregunta necesita un título",
    "Question number {index}" : "Pregunta número {index}",
    "Title of question number {index}" : "Título de la pregunta número {index}",
    "Required" : "Requerido",
    "Delete question" : "Borrar pregunta",
    "Shuffle options" : "Opciones de reordenamiento",
    "Delete" : "Eliminar",
    "Uploading …" : "Cargando...",
    "A long answer for the question “{text}”" : "Una respuesta larga para la pregunta \"{text}\"",
    "Other" : "Otro",
    "A short answer for the question “{text}”" : "Una respuesta corta para la pregunta \"{index}\"",
    "No response" : "Sin respuesta",
    "Delete this response" : "Borrar esta respuesta",
    "This can not be controlled, if the form has a public link or stores responses anonymously." : "Esto no se puede controlar, si el formulario tiene un enlace público o almacena las respuestas anónimamente.",
    "Expired on {date}" : "Expirado el {día}",
    "Expires on {date}" : "Expira el {día}",
    "never" : "nunca",
    "Store responses anonymously" : "Almacenar las respuestas de forma anónima",
    "Allow multiple responses per person" : "Permitir múltiples respuestas por persona",
    "Set expiration date" : "Establece la fecha de expiración",
    "Show expiration date on form" : "Establecer la fecha de expiración del enlace",
    "Group" : "Grupo",
    "Team" : "Equipo",
    "Permissions" : "Permisos",
    "There was an error while adding the share" : "Ha habido un error al añadir el compartido",
    "There was an error while adding the link" : "Ha habido un error al añadir el enlace",
    "There was an error while removing the share" : "Ha habido un error al eliminar el compartido",
    "Share link" : "Compartir liga",
    "Add link" : "Añadir liga",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copy embedding code" : "Copiar código embebido",
    "Remove link" : "Eliminar enlace",
    "Internal link" : "Enlace interno",
    "Only works for logged in accounts with access rights" : "Solo funciona para usuarios con la sesión iniciada en cuentas con permisos de acceso",
    "Permit access to all logged in accounts" : "Permitir acceso a todos los usuarios que han iniciado sesión",
    "Show to all accounts on sidebar" : "Mostrar a todas las cuentas en la barra lateral",
    "View form" : "Ver formulario",
    "View" : "Ver",
    "Edit" : "Editar",
    "Show results" : "Mostrar resultados",
    "View mode" : "Modo de visualización",
    "Share" : "Compartir",
    "Responses are anonymous." : "Las respuestas son anónimas",
    "An asterisk (*) indicates mandatory questions." : "Un asterisco (*) indica preguntas obligatorias.",
    "Expired {relativeDate}." : "Expirado {relativeDate}.",
    "Expires {relativeDate}." : "Expira en {relativeDate}.",
    "There was an error while adding the new question" : "Hubo un error mientras se agregaba la nueva pregunta",
    "There was an error while removing the question" : "Hubo un error mientras se eliminaba la pregunta",
    "Error while saving form" : "Error al guardar el formulario",
    "Loading {title} …" : "Cargando {title}…",
    "Form title" : "Título del formulario",
    "Description" : "Descripción",
    "Add a question" : "Añadir una pregunta",
    "Summary" : "Resumen",
    "Responses" : "Respuestas",
    "There was an error while loading the results" : "Ha habido un error al cargar los resultados",
    "Export successful to {file}" : "Exportado con éxito a {file}",
    "There was an error, while exporting to Files" : "Hubo un error, mientras se exportaba a Archivos",
    "There was an error while removing this response" : "Ha habido un error al eliminar esta respuesta",
    "There was an error while removing responses" : "Ha habido un error al eliminar las respuestas",
    "{amount} responses" : "{amount} respuestas",
    "Download" : "Descargar",
    "Delete all responses" : "Borrar todas las respuestas",
    "Search" : "Buscar",
    "Loading responses …" : "Cargando respuestas ...",
    "No responses yet" : "Aún no hay respuestas",
    "Results of submitted forms will show up here" : "Los resultados de los formularios enviados aparecerán aquí",
    "Are you sure you want to delete all responses of {title}?" : "Estas seguro que deseas borrar todas las respuestas para {título}?",
    "Form settings" : "Configuración del formulario",
    "Sharing" : "Compartiendo",
    "Settings" : "Configuraciones ",
    "Abort" : "Abortar",
    "Submit" : "Enviar",
    "Clear" : "Limpiar",
    "There was an error submitting the form" : "Ha habido un error al enviar el formulario",
    "Submit form" : "Enviar formulario",
    "Submitting form …" : "Enviando formulario …",
    "Thank you for completing the form!" : "¡Gracias por completar el formulario!",
    "Error while saving question" : "Hubo un error mientras se guardaba la pregunta",
    "There was an issue deleting this option" : "Hubo un error mientras se eliminaba esta opción",
    "Form link copied" : "Enlace del formulario copiado",
    "Cannot copy, please copy the link manually" : "No se ha podido copiar, por favor, copia el enlace manualmente",
    "No recommendations. Start typing." : "Sin recomendaciones. Empiece a escribir.",
    "No elements found." : "No se encontraron elementos",
    "Checkboxes" : "Casillas de verificación",
    "Checkbox question title" : "Título de la pregunta de casilla de verificación",
    "Enter your answer" : "Introduzca su respuesta",
    "This question needs a title and at least one answer!" : "¡Esta pregunta necesita un título y al menos una respuesta!",
    "Radio buttons" : "Botones de radio",
    "Radio buttons question title" : "Título de la pregunta de botones de radio",
    "Dropdown" : "Desplegable",
    "Dropdown question title" : "Título de pregunta desplegable",
    "People can pick one option" : "Los usuarios pueden elegir una opción",
    "Pick an option" : "Elija una opción",
    "File" : "Archivo",
    "Short answer" : "Respuesta corta",
    "Short answer question title" : "Título de pregunta de respuesta corta",
    "People can enter a short answer" : "Quien responde puede introducir una respuesta corta",
    "Long text" : "Texto extenso",
    "Long text question title" : "Título de pregunta de respuesta extensa",
    "People can enter a long text" : "Quien responde puede introducir una respuesta extensa",
    "Date" : "Fecha",
    "Date question title" : "Título de la pregunta sobre fecha",
    "People can pick a date" : "Los usuarios pueden elegir una fecha",
    "Pick a date" : "Elige una fecha",
    "Datetime" : "Hora y fecha",
    "Datetime question title" : "Fecha y hora del título de la pregunta",
    "People can pick a date and time" : "Los usuarios pueden elegir una fecha y hora",
    "Pick a date and time" : "Escoge hora y fecha",
    "Time" : "Hora",
    "Time question title" : "Título de la pregunta sobre el tiempo",
    "People can pick a time" : "Los usuarios puede elegir una hora",
    "Pick a time" : "Elige una hora",
    "Color" : "Color",
    "Image" : "Imagen",
    "Document" : "Documento",
    "Presentation" : "Presentación",
    "Spreadsheet" : "Hoja de cálculo",
    "Text" : "Texto",
    "Phone number" : "Número telefónico",
    "Email address" : "Dirección de correo electrónico"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> forms-v5.2.2.tar.gz: forms/l10n/es_MX.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Formularios",
    "{user} has shared the form {formTitle} with you" : "{user} ha compartido el formulario {formTitle} con usted",
    "{user} has shared the form {formTitle} with group {group}" : "{user} ha compartido el formulario {formTitle} con el grupo {group}",
    "Anonymous user" : "Usuario anónimo",
    "A form has been <strong>shared</strong> with you" : "Se ha <strong>compartido</strong> un formulario con usted",
    "Someone <strong>answered</strong> a form" : "Alguien <strong>respondió</strong> a un formulario",
    "Timestamp of data load" : "Timestamp de la carga de datos",
    "Copy" : "Copiar",
    "Anonymous response" : "Respuesta anónima",
    "Shared by %s" : "Compartido por %s ",
    "Forms including questions and submissions" : "Formularios incluyendo preguntas y envíos",
    "responses" : "respuestas",
    "User ID" : "ID de usuario",
    "User display name" : "Nombre a mostrar del usuario",
    "Timestamp" : "Marca de tiempo",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Encuestas y cuestionarios sencillos, autoalojados.",
    "An error occurred while loading the forms list" : "Ha ocurrido un error al cargar la lista de formularios",
    "Form not found" : "Formulario no encontrado",
    "Unable to create a new form" : "No es posible crear un nuevo formulario",
    "Unable to copy form" : "No se ha podido copiar el formulario",
    "New form" : "Nuevo formulario",
    "Shared with you" : "Compartido con usted",
    "No forms created yet" : "Aún no se han creado formularios",
    "Create a form" : "Crear un formulario",
    "Select a form or create a new one" : "Seleccionar un formulario o crear uno nuevo",
    "Please select a form" : "Por favor, escoge un formulario",
    "Create new form" : "Crear nuevo formulario",
    "This form does not exist" : "Este formulario no existe",
    "Form expired" : "El formulario ha expirado",
    "This form has expired and is no longer taking answers" : "Este formulario ha expirado y ya no recibe respuestas",
    "Error while saving configuration" : "Error al guardar la configuración",
    "Error while reloading config" : "Error al recargar la configuración",
    "Form creation" : "Creación del formulario",
    "Restrict form creation to selected groups" : "Restringir la creación de formularios a los grupos seleccionados",
    "Select groups" : "Seleccionar grupos",
    "Form sharing" : "Compartir formularios",
    "Allow sharing by link" : "Permitir compartir a través de enlaces",
    "Allow sharing to all logged in accounts" : "Permitir compartir a todos los usuarios con cuentas",
    "Delete form" : "Eliminar formulario",
    "Expired {relativeDate}" : "Expirado {relativeDate}",
    "Expires {relativeDate}" : "Expira en {relativeDate}",
    "Error while deleting {title}" : "Error al borrar {title}",
    "Form actions" : "Acciones de formulario",
    "Edit form" : "Editar formulario",
    "Share form" : "Compartir formulario",
    "Results" : "Resultados",
    "Copy form" : "Copiar formulario",
    "Are you sure you want to delete {title}?" : "¿Está seguro que desea borrar {título}?",
    "Cancel" : "Cancelar",
    "Options" : "Opciones",
    "Go to previous page" : "Ir a la página anterior",
    "Answer number {index}" : "Respuesta número {index}",
    "Error while saving the answer" : "Error mientras se guardaba la respuesta",
    "Delete answer" : "Borrar respuesta",
    "This question needs a title!" : "Esta pregunta necesita un título",
    "Question number {index}" : "Pregunta número {index}",
    "Title of question number {index}" : "Título de la pregunta número {index}",
    "Required" : "Requerido",
    "Delete question" : "Borrar pregunta",
    "Shuffle options" : "Opciones de reordenamiento",
    "Delete" : "Eliminar",
    "A long answer for the question “{text}”" : "Una respuesta larga para la pregunta \"{text}\"",
    "Other" : "Otro",
    "A short answer for the question “{text}”" : "Una respuesta corta para la pregunta \"{index}\"",
    "No response" : "Sin respuesta",
    "Delete this response" : "Borrar esta respuesta",
    "This can not be controlled, if the form has a public link or stores responses anonymously." : "Esto no se puede controlar, si el formulario tiene un enlace público o almacena las respuestas anónimamente.",
    "Expired on {date}" : "Expirado el {día}",
    "Expires on {date}" : "Expira el {día}",
    "never" : "nunca",
    "Store responses anonymously" : "Almacenar las respuestas de forma anónima",
    "Allow multiple responses per person" : "Permitir múltiples respuestas por persona",
    "Set expiration date" : "Establece la fecha de expiración",
    "Show expiration date on form" : "Establecer la fecha de expiración del enlace",
    "Group" : "Grupo",
    "Team" : "Equipo",
    "Permissions" : "Permisos",
    "There was an error while adding the share" : "Ha habido un error al añadir el compartido",
    "There was an error while adding the link" : "Ha habido un error al añadir el enlace",
    "There was an error while removing the share" : "Ha habido un error al eliminar el compartido",
    "Share link" : "Compartir liga",
    "Add link" : "Añadir liga",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copy embedding code" : "Copiar código embebido",
    "Remove link" : "Eliminar enlace",
    "Internal link" : "Enlace interno",
    "Only works for logged in accounts with access rights" : "Solo funciona para usuarios con la sesión iniciada en cuentas con permisos de acceso",
    "Permit access to all logged in accounts" : "Permitir acceso a todos los usuarios que han iniciado sesión",
    "Show to all accounts on sidebar" : "Mostrar a todas las cuentas en la barra lateral",
    "View form" : "Ver formulario",
    "View" : "Ver",
    "Edit" : "Editar",
    "Show results" : "Mostrar resultados",
    "View mode" : "Modo de visualización",
    "Share" : "Compartir",
    "Responses are anonymous." : "Las respuestas son anónimas",
    "An asterisk (*) indicates mandatory questions." : "Un asterisco (*) indica preguntas obligatorias.",
    "Expired {relativeDate}." : "Expirado {relativeDate}.",
    "Expires {relativeDate}." : "Expira en {relativeDate}.",
    "There was an error while adding the new question" : "Hubo un error mientras se agregaba la nueva pregunta",
    "There was an error while removing the question" : "Hubo un error mientras se eliminaba la pregunta",
    "Error while saving form" : "Error al guardar el formulario",
    "Form title" : "Título del formulario",
    "Description" : "Descripción",
    "Add a question" : "Añadir una pregunta",
    "Summary" : "Resumen",
    "Responses" : "Respuestas",
    "There was an error while loading the results" : "Ha habido un error al cargar los resultados",
    "Export successful to {file}" : "Exportado con éxito a {file}",
    "There was an error, while exporting to Files" : "Hubo un error, mientras se exportaba a Archivos",
    "There was an error while removing this response" : "Ha habido un error al eliminar esta respuesta",
    "There was an error while removing responses" : "Ha habido un error al eliminar las respuestas",
    "{amount} responses" : "{amount} respuestas",
    "Download" : "Descargar",
    "Delete all responses" : "Borrar todas las respuestas",
    "Search" : "Buscar",
    "No responses yet" : "Aún no hay respuestas",
    "Results of submitted forms will show up here" : "Los resultados de los formularios enviados aparecerán aquí",
    "Are you sure you want to delete all responses of {title}?" : "Estas seguro que deseas borrar todas las respuestas para {título}?",
    "Form settings" : "Configuración del formulario",
    "Sharing" : "Compartiendo",
    "Settings" : "Configuraciones ",
    "Abort" : "Abortar",
    "Submit" : "Enviar",
    "Clear" : "Limpiar",
    "There was an error submitting the form" : "Ha habido un error al enviar el formulario",
    "Submit form" : "Enviar formulario",
    "Thank you for completing the form!" : "¡Gracias por completar el formulario!",
    "Error while saving question" : "Hubo un error mientras se guardaba la pregunta",
    "There was an issue deleting this option" : "Hubo un error mientras se eliminaba esta opción",
    "Form link copied" : "Enlace del formulario copiado",
    "Cannot copy, please copy the link manually" : "No se ha podido copiar, por favor, copia el enlace manualmente",
    "No recommendations. Start typing." : "Sin recomendaciones. Empiece a escribir.",
    "No elements found." : "No se encontraron elementos",
    "Checkboxes" : "Casillas de verificación",
    "Checkbox question title" : "Título de la pregunta de casilla de verificación",
    "Enter your answer" : "Introduzca su respuesta",
    "This question needs a title and at least one answer!" : "¡Esta pregunta necesita un título y al menos una respuesta!",
    "Radio buttons" : "Botones de radio",
    "Radio buttons question title" : "Título de la pregunta de botones de radio",
    "Dropdown" : "Desplegable",
    "Dropdown question title" : "Título de pregunta desplegable",
    "People can pick one option" : "Los usuarios pueden elegir una opción",
    "Pick an option" : "Elija una opción",
    "File" : "Archivo",
    "Short answer" : "Respuesta corta",
    "Short answer question title" : "Título de pregunta de respuesta corta",
    "People can enter a short answer" : "Quien responde puede introducir una respuesta corta",
    "Long text" : "Texto extenso",
    "Long text question title" : "Título de pregunta de respuesta extensa",
    "People can enter a long text" : "Quien responde puede introducir una respuesta extensa",
    "Date" : "Fecha",
    "Date question title" : "Título de la pregunta sobre fecha",
    "People can pick a date" : "Los usuarios pueden elegir una fecha",
    "Pick a date" : "Elige una fecha",
    "Datetime" : "Hora y fecha",
    "Datetime question title" : "Fecha y hora del título de la pregunta",
    "People can pick a date and time" : "Los usuarios pueden elegir una fecha y hora",
    "Pick a date and time" : "Escoge hora y fecha",
    "Time" : "Hora",
    "Time question title" : "Título de la pregunta sobre el tiempo",
    "People can pick a time" : "Los usuarios puede elegir una hora",
    "Pick a time" : "Elige una hora",
    "Color" : "Color",
    "Image" : "Imagen",
    "Document" : "Documento",
    "Presentation" : "Presentación",
    "Spreadsheet" : "Hoja de cálculo",
    "Text" : "Texto",
    "Phone number" : "Número telefónico",
    "Email address" : "Dirección de correo electrónico",
    "Loading forms …" : "Cargando formularios …",
    "Uploading …" : "Cargando...",
    "Loading {title} …" : "Cargando {title}…",
    "Loading responses …" : "Cargando respuestas ...",
    "Submitting form …" : "Enviando formulario …"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
